#
# spec file for package cil
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cil
Version:        3.7
Release:        1.2
Summary:        SELinux Common Intermediate Language compiler
License:        BSD-2-Clause
Group:          Development/Languages/Other
URL:            https://github.com/SELinuxProject/selinux
Source0:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/se%{name}c-%{version}.tar.gz
Source1:        https://github.com/SELinuxProject/selinux/releases/download/%{version}/se%{name}c-%{version}.tar.gz.asc
Source2:        cil.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  flex
BuildRequires:  libsepol-devel
BuildRequires:  xmlto
Obsoletes:      %name-doc
Provides:       %name-doc

%description
The SELinux Common Intermediate Language (CIL) is designed to be a language that sits between one or more high level
policy languages (such as the current module language) and the low-level kernel policy representation.

This is a compiler for CIL.

%prep
%setup -q -n secilc-%{version}/

%build
make

%install
%make_install

%files
%defattr(-,root,root,-)
%{_bindir}/secilc
%doc %{_mandir}/man8/*
/usr/bin/secil2conf
/usr/bin/secil2tree

%changelog
* Mon Jul  1 2024 Cathy Hu <cathy.hu@suse.com>
- Update to version 3.7
  https://github.com/SELinuxProject/selinux/releases/tag/3.7
  * Improved man pages
* Tue Dec 19 2023 Cathy Hu <cathy.hu@suse.com>
- Update to version 3.6
  https://github.com/SELinuxProject/selinux/releases/tag/3.6
  * cil: Allow IP address and mask values to be directly written
  * cil: Allow paths in filecon rules to be passed as arguments
  * Add notself support for neverallow rules
  * Improve man pages
  * man pages: Remove the Russian translations
  * Add notself and other support to CIL
  * Add support for deny rules
  * Translations updated from
    https://translate.fedoraproject.org/projects/selinux/
  * Bug fixes
- Remove keys from keyring since they expired:
  - E853C1848B0185CF42864DF363A8AD4B982C4373
    Petr Lautrbach <plautrba@redhat.com>
  - 63191CE94183098689CAB8DB7EF137EC935B0EAF
    Jason Zaman <jasonzaman@gmail.com>
- Add key to keyring:
  - B8682847764DF60DF52D992CBC3905F235179CF1
    Petr Lautrbach <lautrbach@redhat.com>
* Fri Feb 24 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.5
  * Restore error on context rule conflicts
  * Documentation fixes
- Added additional developer key (Jason Zaman)
* Mon May  9 2022 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.4
  * Allow optional file type in genfscon rules
  * Do not copy blockabstracts when inheriting a block
  * Mark as abstract all sub-blocks of an abstract block
  * Do not resolve names to declarations in abstract blocks
  * Ensure that the class in a classcommon is a kernel class
  * Limit the neverallow violations reported
  * Limit the amount of reporting for context rule conflicts
* Thu Nov 11 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.3
  * CIL: Lists are allowed in constraint expressions
  * CIL: Improved situation with duplicate macro and block declarations
  * Added the new `secilc2tree` program to write out CIL AST.
* Tue Mar  9 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.2
  * Improved documentation: fenced code blocks, syntax highlighting,
    custom color theme and more
* Tue Jul 14 2020 Johannes Segitz <jsegitz@suse.com>
- Update to version 3.1
  * add basic test for policy optimization
  * Fix policy optimization test
* Thu Mar  5 2020 Johannes Segitz <jsegitz@suse.de>
- Update to version 3.0
  * Report disabling an optional block only at high verbose levels
  * Fix mlsconstrain segfault
  * Do not dereference perm_value_to_cil when it has not been allocated
  * Add flag to enable policy optimization
  * Allow validatetrans rules to be resolved
- removed pandoc build requirement to allow building on older
  products
* Wed Mar 20 2019 jsegitz@suse.com
- Update to version 2.9
  * Better error handling
* Wed Nov 21 2018 jsegitz@suse.com
- Update to version 2.8. To many changes to list, sorry
* Wed Oct 22 2014 jsegitz@novell.com
- Initial import based on the git repository on 2014-10-22
